@@ -56,6 +56,17 @@ G_DEFINE_TYPE (EogApplication, eog_application, G_TYPE_OBJECT);
 
 #ifdef HAVE_DBUS
 
+/**
+ * eog_application_register_service:
+ * @application: An #EogApplication. 
+ *
+ * Registers #EogApplication<!-- -->'s DBus service, to allow
+ * remote calls. If the DBus service is already registered,
+ * or there is any other connection error, returns %FALSE.
+ *
+ * Returns: %TRUE if the service was registered succesfully. %FALSE
+ * otherwise.
+ **/
 gboolean
 eog_application_register_service (EogApplication *application)
 {
@@ -142,6 +153,14 @@ eog_application_init (EogApplication *eog_application)
 				      EGG_TB_MODEL_NOT_REMOVABLE);
 }
 
+/**
+ * eog_application_get_instance:
+ *
+ * Returns a singleton instance of #EogApplication currently running.
+ * If not running yet, it will create one.
+ *
+ * Returns: a running #EogApplication.
+ **/
 EogApplication *
 eog_application_get_instance (void)
 {
@@ -179,6 +198,19 @@ eog_application_get_empty_window (EogApplication *application)
 	return empty_window;
 }
 
+/**
+ * eog_application_open_window:
+ * @application: An #EogApplication. 
+ * @timestamp: 
+ * @flags: 
+ * @error: 
+ *
+ * Opens and presents an empty #EogWindow to the user. If there is
+ * an empty window already open, this will be used. Otherwise, a
+ * new one will be instantiated.
+ *
+ * Returns: 
+ **/
 gboolean
 eog_application_open_window (EogApplication  *application,
 			     guint32         timestamp,
@@ -202,13 +234,13 @@ eog_application_open_window (EogApplication  *application,
 }
 
 static EogWindow *
-eog_application_get_uri_window (EogApplication *application, GnomeVFSURI *uri)
+eog_application_get_file_window (EogApplication *application, GFile *file)
 {
-	EogWindow *uri_window = NULL;
+	EogWindow *file_window = NULL;
 	GList *windows;
 	GList *l;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (file != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_APPLICATION (application), NULL);
 
 	windows = gtk_window_list_toplevels ();
@@ -219,11 +251,11 @@ eog_application_get_uri_window (EogApplication *application, GnomeVFSURI *uri)
 			
 			if (!eog_window_is_empty (window)) {
 				EogImage *image = eog_window_get_image (window);
-				GnomeVFSURI *window_uri;
+				GFile *window_file;
 				
-				window_uri = eog_image_get_uri (image);
-				if (gnome_vfs_uri_equal (window_uri, uri)) {
-					uri_window = window;
+				window_file = eog_image_get_file (image);
+				if (g_file_equal (window_file, file)) {
+					file_window = window;
 					break;
 				}
 			}
@@ -232,7 +264,7 @@ eog_application_get_uri_window (EogApplication *application, GnomeVFSURI *uri)
 
 	g_list_free (windows);
 	
-	return uri_window;
+	return file_window;
 }
 
 static void
@@ -246,18 +278,32 @@ eog_application_show_window (EogWindow *window, gpointer user_data)
 	gdk_threads_leave ();
 }
 
-static gboolean
-eog_application_real_open_uri_list (EogApplication  *application,
-				    GSList          *uri_list,
-				    guint           timestamp,
-				    EogStartupFlags flags,
-				    GError         **error)
+/**
+ * eog_application_open_file_list:
+ * @application: An #EogApplication.
+ * @file_list: A list of #GFile<!-- -->s.
+ * @timestamp: 
+ * @flags: 
+ * @error: 
+ *
+ * Opens a list of files in a #EogWindow. If an #EogWindow displaying the first
+ * image in the list is already open, this will be used. Otherwise, an empty
+ * #EogWindow is used, either already existing or newly created.
+ *
+ * Returns: 
+ **/
+gboolean
+eog_application_open_file_list (EogApplication  *application,
+				GSList          *file_list,
+				guint           timestamp,
+				EogStartupFlags flags,
+				GError         **error)
 {
 	EogWindow *new_window = NULL;
 
-	if (uri_list != NULL)
-		new_window = eog_application_get_uri_window (application, 
-						     (GnomeVFSURI *) uri_list->data);
+	if (file_list != NULL)
+		new_window = eog_application_get_file_window (application,
+							      (GFile *) file_list->data);
 
 	if (new_window != NULL) {
 		gtk_window_present_with_time (GTK_WINDOW (new_window),
@@ -276,32 +322,58 @@ eog_application_real_open_uri_list (EogApplication  *application,
 			  G_CALLBACK (eog_application_show_window), 
 			  GUINT_TO_POINTER (timestamp));
 
-	eog_window_open_uri_list (new_window, uri_list);
+	eog_window_open_file_list (new_window, file_list);
 
 	return TRUE;
 }
 
+/**
+ * eog_application_open_uri_list:
+ * @application: An #EogApplication.
+ * @uri_list: A list of URIs.
+ * @timestamp: 
+ * @flags: 
+ * @error: 
+ *
+ * Opens a list of images, from a list of URIs. See
+ * eog_application_open_file_list() for details.
+ *
+ * Returns: 
+ **/
 gboolean
 eog_application_open_uri_list (EogApplication  *application,
- 			       GSList          *files,
+ 			       GSList          *uri_list,
  			       guint           timestamp,
  			       EogStartupFlags flags,
  			       GError         **error)
 {
- 	GSList *uri_list = NULL;
+ 	GSList *file_list = NULL;
  
  	g_return_val_if_fail (EOG_IS_APPLICATION (application), FALSE);
  
- 	uri_list = eog_util_string_list_to_uri_list (files);
+ 	file_list = eog_util_string_list_to_file_list (uri_list);
 
- 	return eog_application_real_open_uri_list (application, 
-						   uri_list, 
-						   timestamp,
-						   flags, 
-						   error);
+ 	return eog_application_open_file_list (application,
+					       file_list, 
+					       timestamp,
+					       flags, 
+					       error);
 }
  
 #ifdef HAVE_DBUS
+/**
+ * eog_application_open_uris: 
+ * @application: an #EogApplication
+ * @uris:  A #GList of URI strings.
+ * @timestamp: 
+ * @flags: 
+ * @error: 
+ *
+ * Opens a list of images, from a list of URI strings. See
+ * eog_application_open_file_list() for details.
+ *
+ * Returns: 
+ **/
 gboolean
 eog_application_open_uris (EogApplication  *application,
  			   gchar          **uris,
@@ -309,15 +381,21 @@ eog_application_open_uris (EogApplication  *application,
  			   EogStartupFlags flags,
  			   GError        **error)
 {
- 	GSList *uri_list = NULL;
+ 	GSList *file_list = NULL;
  
- 	uri_list = eog_util_strings_to_uri_list (uris);
+ 	file_list = eog_util_strings_to_file_list (uris);
  
- 	return eog_application_real_open_uri_list (application, uri_list, timestamp,
-						   flags, error);
+ 	return eog_application_open_file_list (application, file_list, timestamp,
+						    flags, error);
 }
 #endif
 
+/**
+ * eog_application_shutdown:
+ * @application: An #EogApplication.
+ *
+ * Takes care of shutting down the Eye of GNOME, and quits.
+ **/
 void
 eog_application_shutdown (EogApplication *application)
 {
@@ -336,6 +414,17 @@ eog_application_shutdown (EogApplication *application)
 	gtk_main_quit ();
 }
 
+/**
+ * eog_application_get_windows:
+ * @application: An #EogApplication.
+ *
+ * Gets the list of existing #EogApplication<!-- -->s. The windows
+ * in this list are not individually referenced, you need to keep
+ * your own references if you want to perform actions that may destroy
+ * them.
+ *
+ * Returns: A new list of #EogWindow<!-- -->s.
+ **/
 GList *
 eog_application_get_windows (EogApplication *application)
 {
@@ -357,6 +446,14 @@ eog_application_get_windows (EogApplication *application)
 	return windows;
 }
 
+/**
+ * eog_application_get_toolbars_model:
+ * @application: An #EogApplication.
+ *
+ * Retrieves the #EogTolbarsModel for the toolbar in #EogApplication.
+ *
+ * Returns: An #EogToolbarsModel.
+ **/
 EggToolbarsModel *
 eog_application_get_toolbars_model (EogApplication *application)
 {
@@ -365,6 +462,12 @@ eog_application_get_toolbars_model (EogApplication *application)
 	return application->toolbars_model;
 }
 
+/**
+ * eog_application_save_toolbars_model:
+ * @application: An #EogApplication.
+ *
+ * Causes the saving of the model of the toolbar in #EogApplication to a file.
+ **/
 void
 eog_application_save_toolbars_model (EogApplication *application)
 {
@@ -374,6 +477,12 @@ eog_application_save_toolbars_model (EogApplication *application)
 						  "1.0");
 }
 
+/**
+ * eog_application_reset_toolbars_model:
+ * @app: an #EogApplication
+ *
+ * Restores the toolbars model to the defaults.
+ **/
 void
 eog_application_reset_toolbars_model (EogApplication *app)
 {
@@ -392,6 +501,13 @@ eog_application_reset_toolbars_model (EogApplication *app)
 }
 
 #ifdef HAVE_DBUS
+/**
+ * eog_application_screensaver_enable:
+ * @application: an #EogApplication.
+ *
+ * Enables the screensaver. Usually necessary after a call to
+ * eog_application_screensaver_disable().
+ **/
 void
 eog_application_screensaver_enable (EogApplication *application)
 {
@@ -399,6 +515,13 @@ eog_application_screensaver_enable (EogApplication *application)
                 totem_scrsaver_enable (application->scr_saver);
 }
 
+/**
+ * eog_application_screensaver_disable:
+ * @application: an #EogApplication.
+ *
+ * Disables the screensaver. Useful when the application is in fullscreen or
+ * similar mode.
+ **/
 void
 eog_application_screensaver_disable (EogApplication *application)
 {
