@@ -1,8 +1,8 @@
 /* Eye Of GNOME -- Print Preview Widget
  *
- * Copyright (C) 2006-2007 The Free Software Foundation
+ * Copyright (C) 2006-2008 The Free Software Foundation
  *
- * Author: Claudio Saavedra <csaavedra@alumnos.utalca.cl>
+ * Author: Claudio Saavedra <csaavedra@gnome.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -378,7 +378,7 @@ eog_print_preview_class_init (EogPrintPreviewClass *klass)
  * EogPrintPreview::image-moved:
  * @preview: the object which received the signal
  *
- * The ::image-moved signal is emmited when the position
+ * The #EogPrintPreview::image-moved signal is emitted when the position
  * of the image is changed.
  */
 	preview_signals [SIGNAL_IMAGE_MOVED] =
@@ -494,11 +494,10 @@ eog_print_preview_new_with_pixbuf (GdkPixbuf *pixbuf)
 
 /**
  * eog_print_preview_new:
- * @void: 
  * 
  * Creates a new #EogPrintPreview widget, setting it to the default values,
- * and leaving the page empty. You still need to set the "image" property
- * to make it useful.
+ * and leaving the page empty. You still need to set the #EogPrintPreview:image
+ * property to make it useful.
  * 
  * Returns: A new and empty #EogPrintPreview widget.
  **/
@@ -514,8 +513,7 @@ eog_print_preview_new (void)
 	
 	gtk_widget_set_events (area,
 			       GDK_EXPOSURE_MASK            |
-			       GDK_POINTER_MOTION_HINT_MASK |
-			       GDK_BUTTON1_MOTION_MASK      |
+			       GDK_POINTER_MOTION_MASK      |
 			       GDK_BUTTON_PRESS_MASK        |
 			       GDK_BUTTON_RELEASE_MASK      |
 			       GDK_KEY_PRESS_MASK);
@@ -951,6 +949,16 @@ motion_notify_event_cb (GtkWidget      *widget,
 		g_signal_emit (G_OBJECT (user_data),
 			       preview_signals
 			       [SIGNAL_IMAGE_MOVED], 0);
+	} else {
+		if (press_inside_image_area (EOG_PRINT_PREVIEW (user_data), event->x, event->y)) {
+		  	GdkCursor *cursor;
+			cursor = gdk_cursor_new_for_display (gtk_widget_get_display (widget),
+							     GDK_FLEUR);
+			gdk_window_set_cursor (widget->window, cursor);
+			gdk_cursor_unref (cursor);
+		} else {
+			gdk_window_set_cursor (widget->window, NULL);
+		}
 	}
 	return FALSE;
 }
@@ -1164,7 +1172,7 @@ eog_print_preview_get_image_position (EogPrintPreview *preview,
 
 /**
  * eog_print_preview_set_image_position:
- * @preview: 
+ * @preview: a #EogPrintPreview 
  * @x: The X coordinate, in inches, or -1 to ignore it.
  * @y: The Y coordinate, in inches, or -1 to ignore it.
  * 
