@@ -58,7 +58,7 @@ static gboolean fullscreen = FALSE;
 static gboolean slide_show = FALSE;
 static gboolean disable_collection = FALSE;
 #if HAVE_DBUS
-static gboolean wait = FALSE;
+static gboolean force_new_instance = FALSE;
 #endif
 static gchar **startup_files = NULL;
 
@@ -68,7 +68,7 @@ static const GOptionEntry goption_options[] =
 	{ "disable-image-collection", 'c', 0, G_OPTION_ARG_NONE, &disable_collection, N_("Disable image collection"), NULL  },
 	{ "slide-show", 's', 0, G_OPTION_ARG_NONE, &slide_show, N_("Open in slide show mode"), NULL  },
 #if HAVE_DBUS
-	{ "new-instance", 'n', 0, G_OPTION_ARG_NONE, &wait, N_("Start a new instance instead of reusing an existing one"), NULL },
+	{ "new-instance", 'n', 0, G_OPTION_ARG_NONE, &force_new_instance, N_("Start a new instance instead of reusing an existing one"), NULL },
 #endif
 	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &startup_files, NULL, N_("[FILE...]") },
 	{ NULL }
@@ -122,7 +122,7 @@ load_files_remote (void)
 	connection = dbus_g_bus_get (DBUS_BUS_STARTER, &error);
 
 	if (connection == NULL) {
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 		g_error_free (error);	
 
  		return FALSE;
@@ -141,7 +141,7 @@ load_files_remote (void)
  					G_TYPE_UCHAR, flags,
  					G_TYPE_INVALID,
  					G_TYPE_INVALID)) {
- 			g_warning (error->message);
+ 			g_warning ("%s", error->message);
  			g_clear_error (&error);
  
  			result = FALSE;
@@ -153,7 +153,7 @@ load_files_remote (void)
  					G_TYPE_UCHAR, flags,
  					G_TYPE_INVALID,
  					G_TYPE_INVALID)) {
- 			g_warning (error->message);
+ 			g_warning ("%s", error->message);
  			g_clear_error (&error);
  			
 			result = FALSE;
@@ -196,7 +196,8 @@ main (int argc, char **argv)
 	set_startup_flags ();
 	
 #ifdef HAVE_DBUS
-	if (!wait && !eog_application_register_service (EOG_APP)) {
+	if (!force_new_instance &&
+	    !eog_application_register_service (EOG_APP)) {
 		if (load_files_remote ()) {
 			g_object_unref (program);
 			return 0;
